@@ -8,7 +8,7 @@ use Data::Dumper;
 
 use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD);
 
-our $VERSION = '1.03';
+our $VERSION = '1.04';
 our $AUTOLOAD;
 
 sub new {
@@ -84,10 +84,10 @@ sub add_aiparams {
     my @keys = ("end_of_speech_timeout", "attention_timeout", "outbound_attention_timeout", "background_file_loops", "background_file_volume", "digit_timeout", "energy_level" );
 
     while ( my ($k,$v) = each(%{$params}) ) {
-	if ( grep { $k } @keys ) {
-            $self->{_prompt}->{$k} = $v + 0;
+	if ( grep { $_ eq $k } @keys ) {
+            $self->{_params}->{$k} = $v + 0;
 	} else {
-            $self->{_prompt}->{$k} = $v;
+            $self->{_params}->{$k} = $v;
 	}
     }
 
@@ -163,10 +163,10 @@ sub set_aipost_prompt {
     my @keys = ("confidence", "barge_confidence", "top_p", "temperature", "frequency_penalty", "presence_penalty");
 
     while ( my ($k,$v) = each(%{$postprompt}) ) {
-	if ( grep { $k } @keys ) {
-            $self->{_prompt}->{$k} = $v + 0;
+	if ( grep { $_ eq $k } @keys ) {
+            $self->{_post_prompt}->{$k} = $v + 0;
 	} else {
-            $self->{_prompt}->{$k} = $v;
+            $self->{_post_prompt}->{$k} = $v;
 	}
     }
 
@@ -180,7 +180,7 @@ sub set_aiprompt {
     my @keys = ("confidence", "barge_confidence", "top_p", "temperature", "frequency_penalty", "presence_penalty");
 
     while ( my ($k,$v) = each(%{$prompt}) ) {
-	if ( grep { $k } @keys ) {
+	if ( grep { $_ eq $k } @keys ) {
             $self->{_prompt}->{$k} = $v + 0;
 	} else {
             $self->{_prompt}->{$k} = $v;
